@@ -1,5 +1,5 @@
 package Astro::FITS::CFITSIO;
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 use strict;
 use Carp;
@@ -19,6 +19,10 @@ my @__names_no_short = qw(
                           fits_get_tile_dim
                           fits_set_tile_dim
                           fits_hdr2str
+                          fits_translate_keyword
+                          fits_translate_keywords
+                          fits_copy_cell2image
+                          fits_copy_image2cell
 		         );
 
 # perl -nle "next unless /^\s*#define\s+fits_/; (undef,\$l,\$s) = split ' '; print \"\$s => '\$l',\"" /usr/local/cfitsio/longnam.h
@@ -27,6 +31,7 @@ my %__names = (
 	       ffiurl => 'fits_parse_input_url',
 	       ffrtnm => 'fits_parse_rootname',
 	       ffrwrg => 'fits_parse_range',
+	       ffrwrgll => 'fits_parse_rangell',
 	       ffourl => 'fits_parse_output_url',
 	       ffexts => 'fits_parse_extspec',
 	       ffextn => 'fits_parse_extnum',
@@ -37,8 +42,10 @@ my %__names = (
 	       ffiopn => 'fits_open_image',
 	       ffomem => 'fits_open_memfile',
 	       ffopen => 'fits_open_file',
+	       ffdkopn => 'fits_open_diskfile',
 	       ffreopen => 'fits_reopen_file',
 	       ffinit => 'fits_create_file',
+	       ffdkinit => 'fits_create_diskfile',
 	       ffimem => 'fits_create_memfile',
 	       fftplt => 'fits_create_template',
 	       ffflus => 'fits_flush_file',
@@ -72,6 +79,7 @@ my %__names = (
 	       ffgthd => 'fits_parse_template',
 	       ffasfm => 'fits_ascii_tform',
 	       ffbnfm => 'fits_binary_tform',
+	       ffbnfmll => 'fits_binary_tformll',
 	       ffgabc => 'fits_get_tbcol',
 	       ffgrsz => 'fits_get_rowsize',
 	       ffgcdw => 'fits_get_col_display_width',
@@ -103,16 +111,20 @@ my %__names = (
 	       ffpkym => 'fits_write_key_dblcmp',
 	       ffpkyt => 'fits_write_key_triple',
 	       ffptdm => 'fits_write_tdim',
+	       ffptdmll => 'fits_write_tdimll',
 	       ffpkns => 'fits_write_keys_str',
 	       ffpknl => 'fits_write_keys_log',
 	       ffpknj => 'fits_write_keys_lng',
+	       ffpknjj => 'fits_write_keys_lnglng',
 	       ffpknf => 'fits_write_keys_fixflt',
 	       ffpkne => 'fits_write_keys_flt',
 	       ffpkng => 'fits_write_keys_fixdbl',
 	       ffpknd => 'fits_write_keys_dbl',
 	       ffcpky => 'fits_copy_key',
 	       ffphps => 'fits_write_imghdr',
+	       ffphpsll => 'fits_write_imghdrll',
 	       ffphpr => 'fits_write_grphdr',
+	       ffphprll => 'fits_write_grphdrll',
 	       ffphtb => 'fits_write_atblhdr',
 	       ffphbn => 'fits_write_btblhdr',
 	       ffpktp => 'fits_write_key_template',
@@ -137,15 +149,21 @@ my %__names = (
 	       ffgkyt => 'fits_read_key_triple',
 	       ffgkls => 'fits_read_key_longstr',
 	       ffgtdm => 'fits_read_tdim',
+	       ffgtdmll => 'fits_read_tdimll',
 	       ffdtdm => 'fits_decode_tdim',
+	       ffdtdmll => 'fits_decode_tdimll',
 	       ffgkns => 'fits_read_keys_str',
 	       ffgknl => 'fits_read_keys_log',
 	       ffgknj => 'fits_read_keys_lng',
+	       ffgknjj => 'fits_read_keys_lnglng',
 	       ffgkne => 'fits_read_keys_flt',
 	       ffgknd => 'fits_read_keys_dbl',
 	       ffghpr => 'fits_read_imghdr',
+	       ffghprll => 'fits_read_imghdrll',
 	       ffghtb => 'fits_read_atblhdr',
+	       ffghtbll => 'fits_read_atblhdrll',
 	       ffghbn => 'fits_read_btblhdr',
+	       ffghbnll => 'fits_read_btblhdrll',
 	       ffh2st => 'fits_header2str',
 	       ffucrd => 'fits_update_card',
 	       ffuky => 'fits_update_key',
@@ -199,23 +217,29 @@ my %__names = (
 	       ffghdn => 'fits_get_hdu_num',
 	       ffghdt => 'fits_get_hdu_type',
 	       ffghad => 'fits_get_hduaddr',
+	       ffghadll => 'fits_get_hduaddrll',
 	       ffghof => 'fits_get_hduoff',
 	       ffgipr => 'fits_get_img_param',
+	       ffgiprll => 'fits_get_img_paramll',
 	       ffgidt => 'fits_get_img_type',
 	       ffgiet => 'fits_get_img_equivtype',
 	       ffgidm => 'fits_get_img_dim',
 	       ffgisz => 'fits_get_img_size',
+	       ffgiszll => 'fits_get_img_sizell',
 	       ffmahd => 'fits_movabs_hdu',
 	       ffmrhd => 'fits_movrel_hdu',
 	       ffmnhd => 'fits_movnam_hdu',
 	       ffthdu => 'fits_get_num_hdus',
 	       ffcrim => 'fits_create_img',
+	       ffcrimll => 'fits_create_imgll',
 	       ffcrtb => 'fits_create_tbl',
 	       ffcrhd => 'fits_create_hdu',
 	       ffiimg => 'fits_insert_img',
+	       ffiimgll => 'fits_insert_imgll',
 	       ffitab => 'fits_insert_atbl',
 	       ffibin => 'fits_insert_btbl',
 	       ffrsim => 'fits_resize_img',
+	       ffrsimll => 'fits_resize_imgll',
 	       ffdhdu => 'fits_delete_hdu',
 	       ffcpfl => 'fits_copy_file',
 	       ffcopy => 'fits_copy_hdu',
@@ -238,76 +262,96 @@ my %__names = (
 	       ffgcno => 'fits_get_colnum',
 	       ffgcnn => 'fits_get_colname',
 	       ffgtcl => 'fits_get_coltype',
+	       ffgtclll => 'fits_get_coltypell',
 	       ffeqty => 'fits_get_eqcoltype',
+	       ffeqtyll => 'fits_get_eqcoltypell',
 	       ffgnrw => 'fits_get_num_rows',
+	       ffgnrwll => 'fits_get_num_rowsll',
 	       ffgncl => 'fits_get_num_cols',
 	       ffgacl => 'fits_get_acolparms',
 	       ffgbcl => 'fits_get_bcolparms',
+	       ffgbclll => 'fits_get_bcolparmsll',
 	       ffiter => 'fits_iterate_data',
 	       ffggpb => 'fits_read_grppar_byt',
+	       ffggpb => 'fits_read_grppar_sbyt',
 	       ffggpui => 'fits_read_grppar_usht',
 	       ffggpuj => 'fits_read_grppar_ulng',
 	       ffggpi => 'fits_read_grppar_sht',
 	       ffggpj => 'fits_read_grppar_lng',
+	       ffggpjj => 'fits_read_grppar_lnglng',
 	       ffggpk => 'fits_read_grppar_int',
 	       ffggpuk => 'fits_read_grppar_uint',
 	       ffggpe => 'fits_read_grppar_flt',
 	       ffggpd => 'fits_read_grppar_dbl',
 	       ffgpxv => 'fits_read_pix',
+	       ffgpxvll => 'fits_read_pixll',
 	       ffgpxf => 'fits_read_pixnull',
+	       ffgpxfll => 'fits_read_pixnullll',
 	       ffgpv => 'fits_read_img',
 	       ffgpf => 'fits_read_imgnull',
 	       ffgpvb => 'fits_read_img_byt',
+	       ffgpvsb => 'fits_read_img_sbyt',
 	       ffgpvui => 'fits_read_img_usht',
 	       ffgpvuj => 'fits_read_img_ulng',
 	       ffgpvi => 'fits_read_img_sht',
 	       ffgpvj => 'fits_read_img_lng',
+	       ffgpvjj => 'fits_read_img_lnglng',
 	       ffgpvuk => 'fits_read_img_uint',
 	       ffgpvk => 'fits_read_img_int',
 	       ffgpve => 'fits_read_img_flt',
 	       ffgpvd => 'fits_read_img_dbl',
 	       ffgpfb => 'fits_read_imgnull_byt',
+	       ffgpfsb => 'fits_read_imgnull_sbyt',
 	       ffgpfui => 'fits_read_imgnull_usht',
 	       ffgpfuj => 'fits_read_imgnull_ulng',
 	       ffgpfi => 'fits_read_imgnull_sht',
 	       ffgpfj => 'fits_read_imgnull_lng',
+	       ffgpfjj => 'fits_read_imgnull_lnglng',
 	       ffgpfuk => 'fits_read_imgnull_uint',
 	       ffgpfk => 'fits_read_imgnull_int',
 	       ffgpfe => 'fits_read_imgnull_flt',
 	       ffgpfd => 'fits_read_imgnull_dbl',
 	       ffg2db => 'fits_read_2d_byt',
+	       ffg2dsb => 'fits_read_2d_sbyt',
 	       ffg2dui => 'fits_read_2d_usht',
 	       ffg2duj => 'fits_read_2d_ulng',
 	       ffg2di => 'fits_read_2d_sht',
 	       ffg2dj => 'fits_read_2d_lng',
+	       ffg2djj => 'fits_read_2d_lnglng',
 	       ffg2duk => 'fits_read_2d_uint',
 	       ffg2dk => 'fits_read_2d_int',
 	       ffg2de => 'fits_read_2d_flt',
 	       ffg2dd => 'fits_read_2d_dbl',
 	       ffg3db => 'fits_read_3d_byt',
+	       ffg3dsb => 'fits_read_3d_sbyt',
 	       ffg3dui => 'fits_read_3d_usht',
 	       ffg3duj => 'fits_read_3d_ulng',
 	       ffg3di => 'fits_read_3d_sht',
 	       ffg3dj => 'fits_read_3d_lng',
+	       ffg3dj => 'fits_read_3d_lnglng',
 	       ffg3duk => 'fits_read_3d_uint',
 	       ffg3dk => 'fits_read_3d_int',
 	       ffg3de => 'fits_read_3d_flt',
 	       ffg3dd => 'fits_read_3d_dbl',
 	       ffgsv => 'fits_read_subset',
 	       ffgsvb => 'fits_read_subset_byt',
+	       ffgsvsb => 'fits_read_subset_sbyt',
 	       ffgsvui => 'fits_read_subset_usht',
 	       ffgsvuj => 'fits_read_subset_ulng',
 	       ffgsvi => 'fits_read_subset_sht',
 	       ffgsvj => 'fits_read_subset_lng',
+	       ffgsvjj => 'fits_read_subset_lnglng',
 	       ffgsvuk => 'fits_read_subset_uint',
 	       ffgsvk => 'fits_read_subset_int',
 	       ffgsve => 'fits_read_subset_flt',
 	       ffgsvd => 'fits_read_subset_dbl',
 	       ffgsfb => 'fits_read_subsetnull_byt',
+	       ffgsfsb => 'fits_read_subsetnull_sbyt',
 	       ffgsfui => 'fits_read_subsetnull_usht',
 	       ffgsfuj => 'fits_read_subsetnull_ulng',
 	       ffgsfi => 'fits_read_subsetnull_sht',
 	       ffgsfj => 'fits_read_subsetnull_lng',
+	       ffgsfjj => 'fits_read_subsetnull_lnglng',
 	       ffgsfuk => 'fits_read_subsetnull_uint',
 	       ffgsfk => 'fits_read_subsetnull_int',
 	       ffgsfe => 'fits_read_subsetnull_flt',
@@ -319,10 +363,12 @@ my %__names = (
 	       ffgcvs => 'fits_read_col_str',
 	       ffgcvl => 'fits_read_col_log',
 	       ffgcvb => 'fits_read_col_byt',
+	       ffgcvsb => 'fits_read_col_sbyt',
 	       ffgcvui => 'fits_read_col_usht',
 	       ffgcvuj => 'fits_read_col_ulng',
 	       ffgcvi => 'fits_read_col_sht',
 	       ffgcvj => 'fits_read_col_lng',
+	       ffgcvjj => 'fits_read_col_lnglng',
 	       ffgcvuk => 'fits_read_col_uint',
 	       ffgcvk => 'fits_read_col_int',
 	       ffgcve => 'fits_read_col_flt',
@@ -335,10 +381,12 @@ my %__names = (
 	       ffgcfs => 'fits_read_colnull_str',
 	       ffgcfl => 'fits_read_colnull_log',
 	       ffgcfb => 'fits_read_colnull_byt',
+	       ffgcfsb => 'fits_read_colnull_sbyt',
 	       ffgcfui => 'fits_read_colnull_usht',
 	       ffgcfuj => 'fits_read_colnull_ulng',
 	       ffgcfi => 'fits_read_colnull_sht',
 	       ffgcfj => 'fits_read_colnull_lng',
+	       ffgcfjj => 'fits_read_colnull_lnglng',
 	       ffgcfuk => 'fits_read_colnull_uint',
 	       ffgcfk => 'fits_read_colnull_int',
 	       ffgcfe => 'fits_read_colnull_flt',
@@ -346,35 +394,45 @@ my %__names = (
 	       ffgcfc => 'fits_read_colnull_cmp',
 	       ffgcfm => 'fits_read_colnull_dblcmp',
 	       ffgdes => 'fits_read_descript',
+	       ffgdesll => 'fits_read_descriptll',
 	       ffgdess => 'fits_read_descripts',
+	       ffgdessll => 'fits_read_descriptsll',
 	       ffgtbb => 'fits_read_tblbytes',
 	       ffpgpb => 'fits_write_grppar_byt',
+	       ffpgpsb => 'fits_write_grppar_sbyt',
 	       ffpgpui => 'fits_write_grppar_usht',
 	       ffpgpuj => 'fits_write_grppar_ulng',
 	       ffpgpi => 'fits_write_grppar_sht',
 	       ffpgpj => 'fits_write_grppar_lng',
+	       ffpgpjj => 'fits_write_grppar_lngj',
 	       ffpgpuk => 'fits_write_grppar_uint',
 	       ffpgpk => 'fits_write_grppar_int',
 	       ffpgpe => 'fits_write_grppar_flt',
 	       ffpgpd => 'fits_write_grppar_dbl',
 	       ffppx => 'fits_write_pix',
+	       ffppxll => 'fits_write_pixll',
 	       ffppxn => 'fits_write_pixnull',
+	       ffppxnll => 'fits_write_pixnullll',
 	       ffppr => 'fits_write_img',
 	       ffpprb => 'fits_write_img_byt',
+	       ffpprsb => 'fits_write_img_sbyt',
 	       ffpprui => 'fits_write_img_usht',
 	       ffppruj => 'fits_write_img_ulng',
 	       ffppri => 'fits_write_img_sht',
 	       ffpprj => 'fits_write_img_lng',
+	       ffpprjj => 'fits_write_img_lnglng',
 	       ffppruk => 'fits_write_img_uint',
 	       ffpprk => 'fits_write_img_int',
 	       ffppre => 'fits_write_img_flt',
 	       ffpprd => 'fits_write_img_dbl',
 	       ffppn => 'fits_write_imgnull',
 	       ffppnb => 'fits_write_imgnull_byt',
+	       ffppnsb => 'fits_write_imgnull_sbyt',
 	       ffppnui => 'fits_write_imgnull_usht',
 	       ffppnuj => 'fits_write_imgnull_ulng',
 	       ffppni => 'fits_write_imgnull_sht',
 	       ffppnj => 'fits_write_imgnull_lng',
+	       ffppnjj => 'fits_write_imgnull_lnglng',
 	       ffppnuk => 'fits_write_imgnull_uint',
 	       ffppnk => 'fits_write_imgnull_int',
 	       ffppne => 'fits_write_imgnull_flt',
@@ -382,41 +440,50 @@ my %__names = (
 	       ffppru => 'fits_write_img_null',
 	       ffpprn => 'fits_write_null_img',
 	       ffp2db => 'fits_write_2d_byt',
+	       ffp2dsb => 'fits_write_2d_sbyt',
 	       ffp2dui => 'fits_write_2d_usht',
 	       ffp2duj => 'fits_write_2d_ulng',
 	       ffp2di => 'fits_write_2d_sht',
 	       ffp2dj => 'fits_write_2d_lng',
+	       ffp2djj => 'fits_write_2d_lnglng',
 	       ffp2duk => 'fits_write_2d_uint',
 	       ffp2dk => 'fits_write_2d_int',
 	       ffp2de => 'fits_write_2d_flt',
 	       ffp2dd => 'fits_write_2d_dbl',
 	       ffp3db => 'fits_write_3d_byt',
+	       ffp3dsb => 'fits_write_3d_sbyt',
 	       ffp3dui => 'fits_write_3d_usht',
 	       ffp3duj => 'fits_write_3d_ulng',
 	       ffp3di => 'fits_write_3d_sht',
 	       ffp3dj => 'fits_write_3d_lng',
+	       ffp3djj => 'fits_write_3d_lnglng',
 	       ffp3duk => 'fits_write_3d_uint',
 	       ffp3dk => 'fits_write_3d_int',
 	       ffp3de => 'fits_write_3d_flt',
 	       ffp3dd => 'fits_write_3d_dbl',
 	       ffpss => 'fits_write_subset',
 	       ffpssb => 'fits_write_subset_byt',
+	       ffpsssb => 'fits_write_subset_sbyt',
 	       ffpssui => 'fits_write_subset_usht',
 	       ffpssuj => 'fits_write_subset_ulng',
 	       ffpssi => 'fits_write_subset_sht',
 	       ffpssj => 'fits_write_subset_lng',
+	       ffpssjj => 'fits_write_subset_lnglng',
 	       ffpssuk => 'fits_write_subset_uint',
 	       ffpssk => 'fits_write_subset_int',
 	       ffpsse => 'fits_write_subset_flt',
 	       ffpssd => 'fits_write_subset_dbl',
+	       ffprwu => 'fits_write_nullrows',
 	       ffpcl => 'fits_write_col',
 	       ffpcls => 'fits_write_col_str',
 	       ffpcll => 'fits_write_col_log',
 	       ffpclb => 'fits_write_col_byt',
+	       ffpclsb => 'fits_write_col_sbyt',
 	       ffpclui => 'fits_write_col_usht',
 	       ffpcluj => 'fits_write_col_ulng',
 	       ffpcli => 'fits_write_col_sht',
 	       ffpclj => 'fits_write_col_lng',
+	       ffpcljj => 'fits_write_col_lnglng',
 	       ffpcluk => 'fits_write_col_uint',
 	       ffpclk => 'fits_write_col_int',
 	       ffpcle => 'fits_write_col_flt',
@@ -429,10 +496,12 @@ my %__names = (
 	       ffpcns => 'fits_write_colnull_str',
 	       ffpcnl => 'fits_write_colnull_log',
 	       ffpcnb => 'fits_write_colnull_byt',
+	       ffpcnsb => 'fits_write_colnull_sbyt',
 	       ffpcnui => 'fits_write_colnull_usht',
 	       ffpcnuj => 'fits_write_colnull_ulng',
 	       ffpcni => 'fits_write_colnull_sht',
 	       ffpcnj => 'fits_write_colnull_lng',
+	       ffpcnjj => 'fits_write_colnull_lnglng',
 	       ffpcnuk => 'fits_write_colnull_uint',
 	       ffpcnk => 'fits_write_colnull_int',
 	       ffpcne => 'fits_write_colnull_flt',
@@ -445,6 +514,7 @@ my %__names = (
 	       ffdrrg => 'fits_delete_rowrange',
 	       ffdrow => 'fits_delete_rows',
 	       ffdrws => 'fits_delete_rowlist',
+	       ffdrwsll => 'fits_delete_rowlistll',
 	       fficol => 'fits_insert_col',
 	       fficls => 'fits_insert_cols',
 	       ffdcol => 'fits_delete_col',
@@ -470,6 +540,7 @@ my %__names = (
 	       ffgtrm => 'fits_remove_group',
 	       ffgtcp => 'fits_copy_group',
 	       ffgtmg => 'fits_merge_groups',
+	       ffmbyt => 'fits_seek',
 	       ffgtcm => 'fits_compact_group',
 	       ffgtvf => 'fits_verify_group',
 	       ffgtop => 'fits_open_group',
